package org.jopendocument.examples;

import java.io.File;
import java.io.IOException;
import java.util.List;

import org.jdom.Document;
import org.jdom.Element;
import org.jdom.JDOMException;
import org.jdom.input.SAXBuilder;
import org.jopendocument.dom.ODPackage;
import org.jopendocument.dom.ODSingleXMLDocument;
import org.jopendocument.dom.text.Heading;
import org.jopendocument.dom.text.Paragraph;

public class SimpleOdt2 {

    private ODSingleXMLDocument contentDom;

    public void run(String[] args) {
        if (args.length == 2) {
            final String inputFileName = args[0];
            final String outputFileName = args[1];

            if (!new File(inputFileName).exists()) {
                System.err.println("Input file not found");
                return;
            }

            try {
                // Open the document containing the styles
                ODPackage outputDocument = new ODPackage(new File("styles.odt"));
                contentDom = outputDocument.toSingle();
                // Parse the input file
                final SAXBuilder builder = new SAXBuilder();
                final Document inputDocument = builder.build(inputFileName);
                // Fill and save our documents
                for (int i = 0; i < 1000; i++) {
                    contentDom.getBody().removeContent();
                    processInputDocument(inputDocument);
                    outputDocument.saveAs(new File(i + outputFileName));
                }
            } catch (Exception e) {
                e.printStackTrace();
            }
        } else {
            System.err.println("Usage: SimpleOdt2 infile outfile");
        }
    }

    void processInputDocument(Document inputDocument) throws JDOMException, IOException {
        final List<Element> movieList = inputDocument.getRootElement().getChildren("movie");
        final int itemsCount = movieList.size();

        for (int i = 0; i < itemsCount; i++) {
            final Element item = movieList.get(i);
            processTitle(item);
            processSynopsis(item);
            processCast(item);
        }
    }

    /*
     * Insert the title and star rating into the output document
     */
    void processTitle(Element movieNode) {
        final Element headingNode = movieNode.getChild("heading");
        final String title = headingNode.getChildText("title");
        final String rating = headingNode.getChildText("rating");

        final Heading heading = new Heading();
        heading.setStyle("Movie_20_Heading");
        heading.addContent(title + " ");
        heading.addStyledContent(rating, "Star_20_Span");

        contentDom.add(heading);
    }

    /*
     * Insert the movie synopsis into the output document
     */
    void processSynopsis(Element movieNode) {
        final List<Element> paragraphs = movieNode.getChild("synopsis").getChildren("para");
        final int paragraphsCount = paragraphs.size();

        for (int i = 0; i < paragraphsCount; i++) {
            final Paragraph paragraph = new Paragraph();
            paragraph.setStyle("Synopsis_20_Para");
            paragraph.addContent(paragraphs.get(i).getText());
            contentDom.add(paragraph);
        }
    }

    /*
     * Insert the movie synopsis into the output document
     */
    void processCast(Element movieNode) {
        final Heading heading = new Heading("The Cast");
        heading.setStyle("Cast_20_Heading");
        contentDom.add(heading);

        final List<Element> actors = movieNode.getChild("credits").getChild("actors").getChildren("actor");
        final int actorsCount = actors.size();

        for (int i = 0; i < actorsCount; i++) {
            final String name = actors.get(i).getChildText("name");
            final String role = actors.get(i).getChildText("role");
            final Paragraph actor = new Paragraph();
            actor.setStyle("Cast_20_Para");
            actor.addContent(name);
            if (role != null && !role.equals("")) {
                actor.addTab();
                actor.addContent(role);
            }
            contentDom.add(actor);
        }
    }

    public static void main(String[] args) {
        long t1 = System.nanoTime();
        final SimpleOdt2 app = new SimpleOdt2();
        app.run(args);
        long t2 = System.nanoTime();
        System.out.println("Time:" + (t2 - t1) / (1000 * 1000) + " ms");
    }

}
